@@ -226,10 +226,10 @@ class Base(Controller):
         server_name = self.app.pargs.__dict__.get('server_name') or self.app.pargs.__dict__.get('sn') or 'C3'
         identity = self.app.pargs.__dict__.get('identity') or self.app.pargs.__dict__.get('i') or os.path.expanduser("~/.ssh/id_rsa")
 
-        from ..ext.sftp_conf import get_sftp_path, write_sftp
-        if not os.path.exists(get_sftp_path()):
-            write_sftp(name=server_name, ip=ip, port=port, user=user,
-                        remote=remote, key_path=identity)
+        from ..ext.sftp_conf import write_sftp
+        
+        write_sftp(name=server_name, ip=ip, port=port, user=user,
+                    remote=remote, key_path=identity)
 
 
     @ex(
